@@ -167,14 +167,19 @@ class UIParser(object):
         if widget_class == 'Line':
             widget_class = 'QFrame'
 
-        # Ignore the parent if it is a container.
+        # Ignore the parent if it is a container
         parent = self.stack.topwidget
+
+        # if is a Menubar on MacOS
+        macMenu = (sys.platform == 'darwin') and (widget_class == 'QMenuBar')
+
         if isinstance(parent, (QtGui.QDockWidget, QtGui.QMdiArea,
                                QtGui.QScrollArea, QtGui.QStackedWidget,
                                QtGui.QToolBox, QtGui.QTabWidget,
-                               QtGui.QWizard)):
+                               QtGui.QWizard)) or macMenu:
             parent = None
 
+
         # See if this is a layout widget.
         if widget_class == 'QWidget':
             if parent is not None:
@@ -619,6 +624,7 @@ class UIParser(object):
 
             text = self.wprops.getProperty(elem, "text")
             icon = self.wprops.getProperty(elem, "icon")
+            whatsThis = self.wprops.getProperty(elem, "whatsThis")
 
             item = self.factory.createQObject("QTableWidgetItem", "item",
                         (), False)
@@ -632,6 +638,9 @@ class UIParser(object):
                 if icon:
                     item.setIcon(icon)
 
+                if whatsThis:
+                    w.horizontalHeaderItem(self.column_counter).setWhatsThis(whatsThis)
+
                 self.column_counter += 1
             elif elem.tag == "row":
                 w.setVerticalHeaderItem(self.row_counter, item)
@@ -642,6 +651,9 @@ class UIParser(object):
                 if icon:
                     item.setIcon(icon)
 
+                if whatsThis:
+                    w.verticalHeaderItem(self.row_counter).setWhatsThis(whatsThis)
+
                 self.row_counter += 1
 
     def createAction(self, elem):
